@@ -686,5 +686,8 @@ class DataprocMetastoreGrpcAsyncIOTransport(DataprocMetastoreTransport):
             )
         return self._stubs["delete_backup"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("DataprocMetastoreGrpcAsyncIOTransport",)
